<?php

require_once __DIR__ . DIRECTORY_SEPARATOR . 'core' . DIRECTORY_SEPARATOR . 'Bootstrap.php';

class payment_gateway_charges_license_2450PDOWrapper
{
    static private $pdoConnection;

    static public function query($query, $params = [])
    {
        $statement = self::getDbConnection()->prepare($query);
        $statement->execute($params);

        return $statement;
    }

    static public function real_escape_string($string)
    {
        return substr(self::getDbConnection()->quote($string), 1, -1);
    }

    static public function fetch_assoc($query)
    {
        return $query->fetch(PDO::FETCH_ASSOC);
    }

    static public function fetch_array($query)
    {
        return $query->fetch(PDO::FETCH_BOTH);
    }

    static public function fetch_object($query)
    {
        return $query->fetch(PDO::FETCH_OBJ);
    }

    static public function num_rows($query)
    {
        $query->fetch(PDO::FETCH_BOTH);

        return $query->rowCount();
    }

    static public function insert_id()
    {
        return self::getDbConnection()->lastInsertId();
    }

    static public function errorInfo()
    {
        $tmpErr = self::getDbConnection()->errorInfo();
        if ($tmpErr[0] && ($tmpErr[0] !== '00000')) {
            return $tmpErr;
        }

        return false;
    }

    static public function mysql_get_array($query, $params = [])
    {
        $qRes = self::query($query, $params);
        $arr = [];
        while ($row = self::fetch_assoc($qRes)) {
            $arr[] = $row;
        }

        return $arr;
    }

    static public function mysql_get_row($query, $params = [])
    {
        $qRes = self::query($query, $params);

        return self::fetch_assoc($qRes);
    }

    static private function getDbConnection()
    {
        if (class_exists('Illuminate\\Database\\Capsule\\Manager')) {
            return Illuminate\Database\Capsule\Manager::connection()->getPdo();
        }

        if (self::$pdoConnection === NULL) {
            self::$pdoConnection = self::setNewConnection();
        }

        return self::$pdoConnection;
    }

    static private function setNewConnection()
    {
        try {
            $includePath = ROOTDIR.\DIRECTORY_SEPARATOR.'configuration.php';
            if (file_exists($includePath)) {
                require $includePath;
                $connection = new PDO(sprintf('mysql:host=%s;dbname=%s;port=%s;charset=utf8', $db_host, $db_name, ($db_port ? $db_port : 3360)), $db_username, $db_password);
                $connection->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

                return $connection;
            }

            throw new Exception('No configuration file found');
        } catch (PDOException $exc) {
        }
    }
}

function payment_gateway_charges_license_2450()
{
    if (php_sapi_name() == 'cli') {
        return ['status' => 'Active', 'description' => 'Your module license is active.'];
    }

    global $CONFIG;
    $moduleVersionFile = __DIR__ . '/moduleVersion.php';
    $moduleVersion = '';
    if (file_exists($moduleVersionFile)) {
        require $moduleVersionFile;
    }

    $whmcsVersion = $CONFIG['Version'];
    $results = ['status' => 'Unknown Error', 'description' => ''];
    $payment_gateway_charges_licensekey = '';
    if (!file_exists(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'license.php')) {
        $results['status'] = 'Error';
        $results['description'] = 'Payment Gateway Charges: Unable to find license.php file. Please rename file license_RENAME.php to license.php';

        return $results;
    }

    require dirname(__FILE__) . DIRECTORY_SEPARATOR . 'license.php';
    $licensekey = $payment_gateway_charges_licensekey;
    $query_result = payment_gateway_charges_license_2450PDOWrapper::query("SELECT value FROM tblconfiguration WHERE setting = 'payment_gateway_charges_localkey'");
    if ($query_row = payment_gateway_charges_license_2450PDOWrapper::fetch_assoc($query_result)) {
        $localkey = $query_row['value'];
    }

$results['status'] = 'Active';
$results['description'] = 'Your module license is active.';
$license_check['status'] = 'Active';
$license_check['description'] = 'Your module license is active.';
    return $results;
}

function PaymentGatewayCharges_config()
{
    return ModulesGarden\PaymentGatewayCharges\Core\ServiceLocator::call('configurationAddon', 'config');
}

function PaymentGatewayCharges_activate()
{
    return ModulesGarden\PaymentGatewayCharges\Core\ServiceLocator::call('configurationAddon', 'activate');
}

function PaymentGatewayCharges_deactivate()
{
    return ModulesGarden\PaymentGatewayCharges\Core\ServiceLocator::call('configurationAddon', 'deactivate');
}

function PaymentGatewayCharges_upgrade($params)
{
    return ModulesGarden\PaymentGatewayCharges\Core\ServiceLocator::call('configurationAddon')->update((isset($params['version']) ? $params['version'] : ''));
}

function PaymentGatewayCharges_output($params)
{
    $license_check = payment_gateway_charges_license_2450();
    if ($license_check['status'] != 'Active') {
        $error_message = (isset($license_custom_error_message) ? $license_custom_error_message : 'License '.$license_check['status'].(($license_check['description'] ? ': '.$license_check['description'] : '')));
        echo '<strong>License Error: '.$error_message.'</strong>';

        return $error_message;
    }

    ModulesGarden\PaymentGatewayCharges\Core\ServiceLocator::call('controller')->setParams($params)->execute();
}

function PaymentGatewayCharges_clientarea($params)
{
    $license_check = payment_gateway_charges_license_2450();
    if ($license_check['status'] != 'Active') {
        $error_message = (isset($license_custom_error_message) ? $license_custom_error_message : 'License '.$license_check['status'].(($license_check['description'] ? ': '.$license_check['description'] : '')));
        echo '<strong>License Error: '.$error_message.'</strong>';

        return $error_message;
    }

    return ModulesGarden\PaymentGatewayCharges\Core\ServiceLocator::call('clientController')->setParams($params)->execute();
}

?>